/* DO NOT EDIT THIS FILE - it is machine generated */
#include <jni.h>
/* Header for class jp_co_infoseek_hp_arton_rjb_RBridge */

#ifndef _Included_jp_co_infoseek_hp_arton_rjb_RBridge
#define _Included_jp_co_infoseek_hp_arton_rjb_RBridge
#ifdef __cplusplus
extern "C" {
#endif
/*
 * Class:     jp_co_infoseek_hp_arton_rjb_RBridge
 * Method:    call
 * Signature: (Ljava/lang/String;Ljava/lang/Object;[Ljava/lang/Object;)Ljava/lang/Object;
 */
JNIEXPORT jobject JNICALL Java_jp_co_infoseek_hp_arton_rjb_RBridge_call
  (JNIEnv *, jobject, jstring, jobject, jobjectArray);

#ifdef __cplusplus
}
#endif
#endif
